@@ -1,5 +1,5 @@
 # -*- coding: utf-8; mode: tcl; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- vim:fenc=utf-8:filetype=tcl:et:sw=4:ts=4:sts=4
-# $Id: portconfigure.tcl 121317 2014-06-23 10:11:51Z jmr@macports.org $
+# $Id: portconfigure.tcl 126863 2014-10-16 18:13:52Z jmr@macports.org $
 #
 # Copyright (c) 2007 - 2014 The MacPorts Project
 # Copyright (c) 2007 Markus W. Weissmann <mww@macports.org>
@@ -227,7 +227,7 @@ proc portconfigure::configure_start {args} {
         {^macports-dragonegg-(\d+\.\d+)-gcc-(\d+\.\d+)$}
             {MacPorts DragonEgg %s with GCC %s}
         {^macports-gcc$}                    {MacPorts GCC (port select)}
-        {^macports-gcc-(\d+\.\d+)$}         {MacPorts GCC %s}
+        {^macports-gcc-(\d+(?:\.\d+)?)$}    {MacPorts GCC %s}
         {^macports-llvm-gcc-4\.2$}          {MacPorts LLVM-GCC 4.2}
     }
     foreach {re fmt} $valid_compilers {
@@ -383,7 +383,7 @@ proc portconfigure::compiler_port_name {compiler} {
         {^apple-gcc-(\d+)\.(\d+)$}                          {apple-gcc%s%s}
         {^macports-clang-(\d+\.\d+)$}                       {clang-%s}
         {^macports-dragonegg-(\d+\.\d+)(-gcc-\d+\.\d+)?$}   {dragonegg-%s%s}
-        {^macports-(llvm-)?gcc-(\d+)\.(\d+)$}               {%sgcc%s%s}
+        {^macports-(llvm-)?gcc-(\d+)(?:\.(\d+))?$}          {%sgcc%s%s}
     }
     foreach {re fmt} $valid_compiler_ports {
         if {[set matches [regexp -inline $re $compiler]] ne ""} {
@@ -548,7 +548,7 @@ proc portconfigure::configure_get_compiler {type {compiler {}}} {
             f77     -
             f90     { return ${prefix}/bin/dragonegg${infix}-gfortran${suffix} }
         }
-    } elseif {[regexp {^macports-gcc(-\d+\.\d+)?$} $compiler -> suffix]} {
+    } elseif {[regexp {^macports-gcc(-\d+(?:\.\d+)?)?$} $compiler -> suffix]} {
         if {$suffix ne ""} {
             set suffix "-mp${suffix}"
         }
@@ -657,13 +657,11 @@ proc portconfigure::configure_main {args} {
 
     if {[tbool use_xmkmf]} {
         parse_environment xmkmf
-        append_to_environment_value xmkmf "IMAKECPP" ${configure.cpp}
         if {[catch {command_exec xmkmf} result]} {
             return -code error "[format [msgcat::mc "%s failure: %s"] xmkmf $result]"
         }
 
         parse_environment xmkmf
-        append_to_environment_value xmkmf "IMAKECPP" ${configure.cpp}
         if {[catch {command_exec "cd ${worksrcpath} && make Makefiles" -varprefix xmkmf} result]} {
             return -code error "[format [msgcat::mc "%s failure: %s"] "make Makefiles" $result]"
         }
